{% extends "base.html" %}

{% block page_title %}{{title}}{% endblock %}

{% block head %}
<script type="text/javascript" src="{{resources}}/notetip.js"></script>
<script type="text/javascript" src="{{resources}}/frameworks.js"></script>
<link rel="stylesheet" type="text/css" href="{{resources}}/frameworks.css" />
<script>
    $(document).ready(main);
</script>
{% endblock %}

{% block title %}
KDE Products
{% endblock %}

{% block content %}
<div class="textblock">
    {% for para in intro %}
    <p>{{ para }}</p>
    {% endfor %}
</div>

{% for product in product_list | sort(attribute='name')%}
<div class="row">
    <div class="col-md-9">
        <div class="product-row">
            <div class="kde-product-row">

                <img src="{% if product.logo_url %} {{ product.logo_url }} {% else %}{{resources}}/default_product.png{% endif %}"
                    width="80px" />

                <div class="kde-product-column">
                    <h4><a name="prod-{{ product.name }}" href="{{ product.href }}">{{ product.fancyname }}</a></h4>
                    <p>
                        {{ product.description }}
                    </p>
                    <div>
                        <b>Maintainer{% if product.maintainers | length > 1 %}s{% endif %}:</b>
                        {% for maintainer in product.maintainers %}
                        <a
                            href="mailto:{{ maintainer.email }}">{{ maintainer.name }}</a>{% if not loop.last %},{% endif %}
                        {% else %}
                        <a href="mailto:kde-devel@kde.org">The KDE Community</a>
                        {% endfor %}
                    </div>
                    {% if product.platforms %}
                    <p>
                        <b>Platform{% if product.platforms | length > 1 %}s{% endif %}:</b> {{ product.platforms | sort | join(' | ') }}
                    </p>
                    {% endif %}
                    {% if qch or man %}
                    <li class="prod-download">
                        {% if qch %} [<a href="qch/{{product.name}}.qch">QCH file</a>]{% endif %}
                        {% if man %} <a href="qch/{{product.name}}.man">MAN</a>{% endif %}
                    </li>
                    {% endif %}
                </div>
            </div> <!-- row -->
        </div> <!-- product-row -->
    </div>
</div> <!-- row -->
{% endfor %}

{% endblock content %}

{% block sidebar %}
{% include "frontpage-sidebar.html" %}
{% endblock %}