<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="utf-8">
  <meta http-equiv="X-UA-Compatible" content="IE=edge">
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <title>{% block page_title %}{% endblock %}</title>

  <style type="text/css">
    .cp-doNotDisplay { display: none; }
    @media aural, braille, handheld, tty { .cp-doNotDisplay { display: inline; speak: normal; }}
    .cp-edit { text-align: right; }
    @media print, embossed { .cp-edit { display: none; }}
  </style>

  <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
  <meta http-equiv="Content-Style-Type" content="text/css" />
  <link rel="meta" href="https://www.kde.org/labels.rdf" type="application/rdf+xml" title="ICRA labels" />
  <meta name="trademark" content="KDE e.V." />
  <meta name="description" content="KDE products API documentation" />
  <meta name="MSSmartTagsPreventParsing" content="true" />
  <meta name="robots" content="all" />
  <meta name="no-email-collection" content="http://www.unspam.com/noemailcollection" />
  {% if kapidox_version %}
    <meta name="generator" content="kapidox {{ kapidox_version }}" />
  {% endif %}
  <script type="text/javascript" src="{{resources}}/3rd-party/jquery/jquery-3.1.0.min.js"></script>
  <script type="text/javascript" src="dynsections.js"></script>
  <link rel="shortcut icon" href="{{resources}}/favicon.ico" />
  <link rel="icon" href="{{resources}}/favicon.ico" />
  <!-- CSS can be edited in https://invent.kde.org/websites/aether-sass -->
  <link rel="stylesheet" type="text/css" href="https://cdn.kde.org/aether-devel/bootstrap.css" />
  {% if doxygencss %}
    <link rel="stylesheet" type="text/css" href="{{doxygencss}}" />
  {% endif %}
  <link rel="stylesheet" type="text/css" href="https://cdn.kde.org/aether-devel/aether-sidebar.css" />
  {% block head %}{% endblock %}
</head>

<body>

  <ul class="sr-only">
    <li><a href="#cp-content" accesskey="2">Skip to content</a></li>
    <li><a href="#cp-menu" accesskey="5">Skip to link menu</a></li>
  </ul>

  <main class="body no-js">
    <header class="header">
      <nav class="navbar">
        <ol class="breadcrumb navbar-nav">
          <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarsExampleDefault" aria-controls="navbarsExampleDefault" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
          </button>
          {% for entry in breadcrumbs.entries %}
            <li class="breadcrumb-link">
              <a href="{{ entry.href }}">{{ entry.text }}</a>
            </li>
          {% endfor %}
        </ol>
      </nav>
    </header>

    <aside class="sidebar">
      {% block sidebar %}{% endblock %}
    </aside>

    <article class="content">
      <h1 class="content-title">
        {% block title %}{% endblock %}
        <form action="search.html" method="get" class="form-inline">
          <div id="search" class="input-group ml-auto">
            <input type="text" id="search-input" name="query" aria-label="Search input" class="form-control" placeholder="Search...">
            <span class="input-group-btn">
              <button type="submit" class="btn btn-default" aria-label="Search">
                <span class="glyphicon glyphicon-search"></span>
              </button>
            </span>
          </div>
        </form>
      </h1>

      {% block content %}{% endblock %}

      <footer class="footer bg-primary">
        <div id="footer-text" class="center-block col-md-7" style="float:none;">
            {% include 'footer.html' %}
        </div>
        {#{% block footer %}
        <div id="footer-text" class="col-md-5 center-block" style="float: none;">
          <p>Generated by <a href="https://api.kde.org/frameworks/kapidox/html/index.html">KApiDox</a>, a <a href="https://www.kde.org">KDE</a> product.</p>
        </div>
        {% endblock %}#}
      </footer>
    </article>
  </main>
  <script>
    const toggler = document.querySelector('.navbar-toggler');
    const body = document.querySelector('.body');
    body.classList.remove('no-js');
    toggler.addEventListener('click', () => {
      body.classList.toggle('sidebar-active');
    });
  </script>

<!--
WARNING: DO NOT SEND MAIL TO THE FOLLOWING EMAIL ADDRESS! YOU WILL
BE BLOCKED INSTANTLY AND PERMANENTLY!
<a href="mailto:aaaatrap-45abe0e0c3bebc77@kde.org">Block me</a>
WARNING END
-->

</body>
</html>
